const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CleanPlugin = require('clean-webpack-plugin');
const CopyWebpackPlugin = require('copy-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const dist = path.resolve(__dirname, 'dist');
const port = 9000;

const extractSass = new ExtractTextPlugin('[name].css');

function getPath(_path) {
  return path.resolve(__dirname, _path);
}

var config = {
  context: path.resolve(__dirname),
  entry: getPath('./demo/index'),
  output: {
    path: dist,
    filename: '[name].js'
  },
  devtool: 'source-map',
  module: {
    rules: [
      {
        test: /\.scss$/,
        use: extractSass.extract([
          {
            loader: 'css-loader',
            options: {
              sourceMap: true
            }
          },
          {
            loader: 'sass-loader',
            options: {
              sourceMap: true
            }
          }
        ])
      },
      {
        test: /\.json$/,
        loader: 'json-loader'
      },
      {
        test: /\.js$/,
        exclude: [/node_modules/],
        loader: 'babel-loader',
        options: {
          cacheDirectory: true
        }
      }
    ]
  },
  plugins: [
    new CleanPlugin([dist]),
    new HtmlWebpackPlugin({
      filename: `index.html`,
      template: `./demo/index.html`,
      inject: true,
      minify: {
        removeComments: false,
        collapseWhitespace: false,
        minifyJS: false
      }
    }),
    extractSass
  ]
};

config.devServer = {
  disableHostCheck: true,
  contentBase: dist,
  port: port,
  hot: true,
  inline: true
};

config.plugins.push(new webpack.HotModuleReplacementPlugin());

module.exports = config;
